<?php
/**
* @title        Minitek Slider
* @copyright    Copyright (C) 2011-2021 Minitek, All rights reserved.
* @license      GNU General Public License version 3 or later.
* @author url   http://www.minitek.gr/
* @developers   Minitek.gr
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

class MinitekSliderLibBaseSliderJavascript
{
	public function loadSliderJavascript($slider_params, $widgetID, $totalCount)
	{
		$document = JFactory::getDocument();

		$javascript = "
			;(function($) {
				$(function() {
		";

			$javascript .= $this->initializeSlider($slider_params, $widgetID, $totalCount);

			// Progress bar
			if ($slider_params['slider_progressbar'])
			{
				$javascript .= $this->initializeProgressBar($widgetID);
			}

			// Slider Parallax
			if ($slider_params['slider_parallax'])
			{
				$javascript .= $this->initializeSliderParallax($widgetID);
			}

			// Horizontal Navigator
			if ($slider_params['slider_navigator'])
			{
				$javascript .= $this->initializeHorizontalNavigator($slider_params, $widgetID);
			}

			// Media slider
			if ($slider_params['slider_theme'] == 'media_slider')
			{
				$javascript .= $this->initializeMediaSlider($widgetID);
			}

			// Hover box
			if ($slider_params['slider_hb'])
			{
				$javascript .= $this->initializeHoverBox($slider_params['slider_hb_effect'], $widgetID);
			}

		$javascript .= "
				})
			})(jQuery);	
		";

		//$document->addScriptDeclaration($javascript);
		$document->addCustomTag('<script type="text/javascript">'.$javascript.'</script>');

	}

	public function initializeSlider($slider_params, $widgetID, $totalCount)
	{
		$draggable = $slider_params['slider_drag'] ? "'>1'" : 'false';
		$freeScroll = $slider_params['slider_free_scroll'] ? 'true' : 'false';
		$load_more = $slider_params['slider_load_more'];
		$wrapAround = ($slider_params['slider_rewind'] && !$load_more) ? 'true' : 'false';
		$groupCells = $slider_params['slider_group_items'] ? 'true' : 'false';
		$autoplay_speed = (int)$slider_params['slider_autoplay_speed'];
		$autoPlay = $slider_params['slider_autoplay'] ? $autoplay_speed : 'false';
		$fullscreen = $slider_params['slider_fullscreen'] ? 'true' : 'false';
		$fade = $slider_params['slider_fade'] ? 'true' : 'false';
		$adaptiveHeight = $slider_params['slider_adaptive_height'] ? 'true' : 'false';

		if (!isset($slider_params['slider_drag_threshold']) || !$slider_params['slider_drag_threshold'])
		{
			$slider_params['slider_drag_threshold'] = 3;
		}

		$dragThreshold = (int)$slider_params['slider_drag_threshold'];

		if (!isset($slider_params['slider_selected_attraction']) || !$slider_params['slider_selected_attraction'])
		{
			$slider_params['slider_selected_attraction'] = 0.025;
		}

		$selectedAttraction = $slider_params['slider_selected_attraction'];

		if (!isset($slider_params['slider_friction']) || !$slider_params['slider_friction'])
		{
			$slider_params['slider_friction'] = 0.28;
		}

		$friction = $slider_params['slider_friction'];

		if (!isset($slider_params['slider_free_scroll_friction']) || !$slider_params['slider_free_scroll_friction'])
		{
			$slider_params['slider_free_scroll_friction'] = 0.075;
		}

		$freeScrollFriction = $slider_params['slider_free_scroll_friction'];

		$lazyLoad = $slider_params['slider_lazyload'] ? 'true' : 'false';
		$cellAlign = $slider_params['slider_cell_align'];
		$contain = $slider_params['slider_contain'] ? 'true' : 'false';
		$rightToLeft = $slider_params['slider_rtl'] ? 'true' : 'false';
		$prevNextButtons = $slider_params['slider_arrows'] ? 'true' : 'false';
		$pageDots = $slider_params['slider_bullets'] ? 'true' : 'false';

		$fullscreenChange = '';
		$navigator = $slider_params['slider_navigator'];

		if ($navigator)
		{
			$fullscreenChange = "fullscreenChange: function(isFullscreen) {
				_navigator.flickity('resize');
				if (isFullscreen)
				{
					fix_heights('');

					// Fix media slider height
					var media_db_height = $('#mslider_".$widgetID."').find('.mslider-media-db').outerHeight();
					$('#mslider_".$widgetID.".mslider_media_slider.is-fullscreen').css('height', 'calc(100% - '+media_db_height+'px)');
				}
				else 
				{
					fix_heights('100%');
				}
			}";
		}
		else 
		{
			$fullscreenChange = "fullscreenChange: function(isFullscreen) {
				if (isFullscreen)
				{
					fix_heights('');

					// Fix media slider height
					var media_db_height = $('#mslider_".$widgetID."').find('.mslider-media-db').outerHeight();
					$('#mslider_".$widgetID.".mslider_media_slider.is-fullscreen').css('height', 'calc(100% - '+media_db_height+'px)');
				}
				else 
				{
					fix_heights('100%');
				}
			}";
		}

		$arrows_color = $slider_params['slider_arrows_color'];
		$site_path = JURI::root();
		$group_cells = $slider_params['slider_group_items'];

		$javascript = "
			// Show slider
			$('#mslider_".$widgetID."').show();

			// Initialize slider
			var _slider = $('#mslider_".$widgetID."').flickity({
				draggable: ".$draggable.",
				freeScroll: ".$freeScroll.",
				wrapAround: ".$wrapAround.",
				groupCells: ".$groupCells.",
				autoPlay: ".$autoPlay.",
				pauseAutoPlayOnHover: false,
				fullscreen: ".$fullscreen.",
				fade: ".$fade.",
				adaptiveHeight: ".$adaptiveHeight.",
				hash: false,
				dragThreshold: ".$dragThreshold.",
				selectedAttraction: ".$selectedAttraction.",
				friction: ".$friction.",
				freeScrollFriction: ".$freeScrollFriction.",
				imagesLoaded: true,
				lazyLoad: ".$lazyLoad.",
				cellSelector: '.mslider-item',
				initialIndex: 0,
				accessibility: true,
				setGallerySize: true,
				resize: true,
				cellAlign: '".$cellAlign."',
				contain: ".$contain.",
				rightToLeft: ".$rightToLeft.",
				percentPosition: true,
				prevNextButtons: ".$prevNextButtons.",
				pageDots: ".$pageDots.",
				on: {
			    ready: function() {
					$('#mslider_".$widgetID."').addClass('flickity-ready');
					fix_heights('100%');
			    },
					".$fullscreenChange."
			  }
			});

			// Fix item heights
			function fix_heights(h)
			{
				$('#mslider_".$widgetID.".mslider_image_slider').find('.mslider-item.no_image').css('height', h);
				$('#mslider_".$widgetID.".mslider_article_slider_1').find('.mslider-item.no_image').css('height', h);
				$('#mslider_".$widgetID.".mslider_article_slider_2').find('.mslider-item.no_image').css('height', h);
				$('#mslider_".$widgetID.".mslider_article_slider_5').find('.mslider-item.no_image').css('height', h);
			}

			//////////////////////////////
			// Load more items in slider
			//////////////////////////////
			var load_more = ".$load_more.";

			if (load_more)
			{
				var site_path = '".$site_path."';
				var slider = _slider.data('flickity');
				var cells_loaded = slider.cells.length;
				var total_items = parseInt(".$totalCount.", 10);
				var items_left = total_items - cells_loaded;
				var arrows_color = '".$arrows_color."';
				var navigator = ".$navigator.";
				var group_cells = ".$group_cells.";

				if (items_left > 0)
				{
					var next_clone = $('#mslider_".$widgetID." .flickity-button.next').clone(true).addClass('cloned').insertAfter('#mslider_".$widgetID." .flickity-button.next').addClass('disabled').hide();
					next_clone.attr('data-page', '2');

					// Create spinner
					var opts = {
					  lines: 9,
					  length: 4,
					  width: 3,
					  radius: 3,
					  corners: 1,
					  rotate: 0,
					  direction: 1,
					  color: arrows_color,
					  speed: 1,
					  trail: 52,
					  shadow: false,
					  hwaccel: false,
					  className: 'spinner',
					  zIndex: 2e9,
					  top: '50%',
					  left: '50%'
					};
					next_clone.append('<div class=\"mslider-loader\"></div>');
					next_clone.find('.mslider-loader').append(new Spinner(opts).spin().el);

					// Corner case: 1st page has 0 or 1 slides
					if (slider.slides.length == 0 || slider.slides.length == 1) 
					{
						$('#mslider_".$widgetID." .flickity-button.next').hide();
						next_clone.removeClass('disabled').removeAttr('disabled').show();
					}

					// Toggle cloned next button
					_slider.on( 'change.flickity', function( event, index )
					{
						if (group_cells)
						{
							var cells_loaded = slider.slides.length;
						}
						else
						{
							var cells_loaded = slider.cells.length;
						}

						items_left = total_items - slider.cells.length;

						if (items_left > 0)
						{
							if (index == cells_loaded - 1)
							{
								$('#mslider_".$widgetID." .flickity-button.next').hide();
								next_clone.removeClass('disabled').show();
							}
							else
							{
								$('#mslider_".$widgetID." .flickity-button.next').show();
								next_clone.addClass('disabled').hide();
							}
						}
						else
						{
							$('#mslider_".$widgetID." .flickity-button.next').show();
							next_clone.remove();
						}
					});

					// Load more items
					next_clone.on('click', function(e)
					{
						e.preventDefault();

						if ($(this).hasClass('disabled')) 
						{
							return false;
						}

						// Check if there is a pending ajax request
						if (typeof ajax_request !== 'undefined') 
						{
							ajax_request.abort();
						}

						if (group_cells)
						{
							var new_cells_loaded = slider.slides.length;
							var nav_cells_loaded = slider.cells.length;
						}
						else
						{
							var new_cells_loaded = slider.cells.length;
							var nav_cells_loaded = slider.cells.length;
						}

						var page = next_clone.attr('data-page');
						page = parseInt(page, 10);
						var new_page = page + 1;

						// Increment data-page
						next_clone.attr('data-page', new_page);

						// Show loader
						next_clone.addClass('disabled');
						next_clone.find('svg').hide();
						$(this).find('.mslider-loader').show();
						_slider.addClass('is-loading');

						// Ajax
						ajax_request = $.ajax({
							type: 'POST',
							url: site_path+'index.php?option=com_minitekslider&task=slider.getContent&widget_id=".$widgetID."&page=' + page + '&type=slider',
							success: function(response)
							{
								if (response.length > 3)
								{
									var items_array = response.split('<div class=\"mslider-media-db\">');
									var items = items_array[0];
									var dbs = items_array[1];

									// Update detail box in media slider
									$('#mslider_".$widgetID."').find('.mslider-media-db').append(dbs);
									$('#mslider_".$widgetID." .mslider-media-db .mslider-detail-box').each(function(index){
										$(this).attr('data-selectedindex', index);
									});

									// Load items
									_slider.flickity( 'append', $(items) );
									_slider.flickity( 'select', new_cells_loaded );

									// Fix heights
									if ($('#mslider_".$widgetID."').hasClass('is-fullscreen'))
									{
										fix_heights('');
									}
									else 
									{
										fix_heights('100%');
									}

									// Fade in items
									_slider.one( 'select.flickity', function( event, index ) {
										var flkt = _slider.data('flickity');
										$(flkt.selectedElement).removeClass('mslider-item-hidden');
										$(flkt.selectedElement).nextAll().removeClass('mslider-item-hidden');
										_slider.flickity('resize');
									});

									// Update Navigator
									if (navigator)
									{
										nav_ajax_request = $.ajax({
											type: 'POST',
											url: site_path+'index.php?option=com_minitekslider&task=slider.getContent&widget_id=".$widgetID."&page=' + page + '&type=navigator',
											success: function(response)
											{
												if (response.length > 3)
												{
													// Load new items
													_navigator.flickity( 'append', $(response) );
													_slider.flickity( 'select', new_cells_loaded );

													$('#mslider_nav_".$widgetID."').find('.mslider-nav-item').removeClass('mslider-item-hidden');
													_slider.removeClass('is-loading');
												}
											},
											error: function(XMLHttpRequest, textStatus, errorThrown) {
												console.log(errorThrown);
											}
										});
									}
									else
									{
										_slider.flickity( 'select', new_cells_loaded );
										_slider.removeClass('is-loading');
									}

									// Hide loader
									next_clone.find('svg').show();
									next_clone.find('.mslider-loader').hide();
								}
								else
								{
									$('#mslider_".$widgetID." .flickity-button.next').show();
									next_clone.remove();
									_slider.removeClass('is-loading');
								}
							},
							error: function(XMLHttpRequest, textStatus, errorThrown) 
							{
								console.log(errorThrown);
							}
						});
					});
				}
			}
		";

		return $javascript;
	}

	public function initializeHorizontalNavigator($slider_params, $widgetID)
	{
		$draggable = $slider_params['slider_drag'] ? "'>1'" : 'false';
		$freeScroll = $slider_params['slider_free_scroll'] ? 'true' : 'false';
		$load_more = $slider_params['slider_load_more'];

		if (!isset($slider_params['slider_drag_threshold']) || !$slider_params['slider_drag_threshold'])
		{
			$slider_params['slider_drag_threshold'] = 3;
		}

		$dragThreshold = (int)$slider_params['slider_drag_threshold'];

		if (!isset($slider_params['slider_selected_attraction']) || !$slider_params['slider_selected_attraction'])
		{
			$slider_params['slider_selected_attraction'] = 0.025;
		}

		$selectedAttraction = $slider_params['slider_selected_attraction'];

		if (!isset($slider_params['slider_friction']) || !$slider_params['slider_friction'])
		{
			$slider_params['slider_friction'] = 0.28;
		}

		$friction = $slider_params['slider_friction'];

		if (!isset($slider_params['slider_free_scroll_friction']) || !$slider_params['slider_free_scroll_friction'])
		{
			$slider_params['slider_free_scroll_friction'] = 0.075;
		}

		$freeScrollFriction = $slider_params['slider_free_scroll_friction'];

		$rightToLeft = $slider_params['slider_rtl'] ? 'true' : 'false';
		$prevNextButtons = $slider_params['slider_navigator_arrows'] ? 'true' : 'false';

		$javascript = "
			// Show navigator
			$('#mslider_nav_".$widgetID."').show();

			// Initialize navigator
			var _navigator = $('#mslider_nav_".$widgetID."').flickity({
				draggable: ".$draggable.",
				freeScroll: ".$freeScroll.",
				groupCells: false,
				asNavFor: '#mslider_".$widgetID."',
				dragThreshold: ".$dragThreshold.",
				selectedAttraction: ".$selectedAttraction.",
				friction: ".$friction.",
				freeScrollFriction: ".$freeScrollFriction.",
				imagesLoaded: true,
				lazyLoad: false,
				cellSelector: '.mslider-nav-item',
				accessibility: true,
				setGallerySize: true,
				resize: true,
				contain: true,
				rightToLeft: ".$rightToLeft.",
				percentPosition: true,
				prevNextButtons: ".$prevNextButtons.",
				pageDots: false,
			});
		";

		return $javascript;
	}

	public function initializeProgressBar($widgetID)
	{
		$javascript = "
			var _progressBar = $('#mslider_progressbar_".$widgetID."');
			_slider.on( 'scroll.flickity', function( event, progress ) {
				progress = Math.max( 0, Math.min( 1, progress ) );
				_progressBar.width( progress * 100 + '%' );
			});
		";

		return $javascript;
	}

	public function initializeSliderParallax($widgetID)
	{
		$javascript = "
			var slider = _slider.data('flickity');
			var _imgs = $('#mslider_".$widgetID." .mslider-item img');
			_slider.on( 'scroll.flickity', function( event, progress ) {
			  	slider.slides.forEach( function( slide, i ) {
					var img = _imgs[i];
					var x = ( slide.target + slider.x ) * -1/3;
					if (img)
					{
						img.style.transform = 'translateX( ' + x  + 'px)';
					}
				});
			});
		";

		return $javascript;
	}

	public function initializeMediaSlider($widgetID)
	{
		$javascript = "
		$('#mslider_".$widgetID." .mslider-media-db').insertAfter('#mslider_".$widgetID." .flickity-viewport');

			$('#mslider_".$widgetID." .mslider-media-db .mslider-detail-box').each(function(index){
				$(this).attr('data-selectedindex', index);
			});

			$('#mslider_".$widgetID." .mslider-media-db .mslider-detail-box[data-selectedindex=\"0\"]').show();

			_slider.on( 'select.flickity', function(event, index) {
				$('#mslider_".$widgetID." .mslider-media-db .mslider-detail-box').hide();
				$('#mslider_".$widgetID." .mslider-media-db .mslider-detail-box[data-selectedindex=\"'+ index +'\"]').show();
			})
		";

		return $javascript;
	}

	public function initializeHoverBox($hoverBoxEffect, $widgetID)
	{
		$javascript = "
			// Hover effects
			var hoverBoxEffect = '".$hoverBoxEffect."';

			// Hover box trigger
			var triggerHoverBox = function triggerHoverBox() {

				// Hover effects
				$('#mslider_".$widgetID."').on( 'mouseenter', '.mslider-item', function(e)
				{
					if (hoverBoxEffect == 'no') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('hoverShow');
					}
					else if (hoverBoxEffect == '1') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('hoverFadeIn');
					}
					else if (hoverBoxEffect == '2') 
					{
						$(this).stop().addClass('perspective');
						$(this).find('.mslider-item-outer-cont').stop().addClass('flip flipY hoverFlipY');
					}
					else if (hoverBoxEffect == '3') 
					{
						$(this).stop().addClass('perspective');
						$(this).find('.mslider-item-outer-cont').stop().addClass('flip flipX hoverFlipX');
					}
					else if (hoverBoxEffect == '4') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('animated slideInRight');
					}
					else if (hoverBoxEffect == '5') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('animated slideInLeft');
					}
					else if (hoverBoxEffect == '6') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('animated slideInTop');
					}
					else if (hoverBoxEffect == '7') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('animated slideInBottom');
					}
					else if (hoverBoxEffect == '8') 
					{
						$(this).find('.mslider-hover-box').stop().addClass('animated msliderzoomIn');
					}
				});

				$('#mslider_".$widgetID."').on( 'mouseleave', '.mslider-item', function(e)
				{
					if (hoverBoxEffect == 'no') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('hoverShow');
					}
					else if (hoverBoxEffect == '1') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('hoverFadeIn');
					}
					else if (hoverBoxEffect == '2') 
					{
						$(this).find('.mslider-item-outer-cont').stop().removeClass('hoverFlipY');
					}
					else if (hoverBoxEffect == '3') 
					{
						$(this).find('.mslider-item-outer-cont').stop().removeClass('hoverFlipX');
					}
					else if (hoverBoxEffect == '4') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('slideInRight');
					}
					else if (hoverBoxEffect == '5') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('slideInLeft');
					}
					else if (hoverBoxEffect == '6') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('slideInTop');
					}
					else if (hoverBoxEffect == '7') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('slideInBottom');
					}
					else if (hoverBoxEffect == '8') 
					{
						$(this).find('.mslider-hover-box').stop().removeClass('msliderzoomIn');
					}
				});
			};

			triggerHoverBox();
		";

		return $javascript;
	}
}
