<?php
/**
* @title        Minitek Slider
* @copyright    Copyright (C) 2011-2019 Minitek, All rights reserved.
* @license      GNU General Public License version 3 or later.
* @author url   http://www.minitek.gr/
* @developers   Minitek.gr
*/

defined('_JEXEC') or die('Restricted access');

class MinitekSliderLibSourceFolder
{
	// Get Images count from folder
	public function getFolderImagesCount($data_source, $globalLimit)
	{
		if (!isset($data_source['image_folder']) || !$data_source['image_folder'])
		{
			if (strstr($data_source['fold_folder'], '/'))
			{
				$folder = substr($data_source['fold_folder'], strrpos($data_source['fold_folder'], '/') + 1);
			}
			else
			{
				$folder = $data_source['fold_folder'];
			}

			$directory = 'media/minitekslider/'.$folder.'/';
		}
		else
		{
			$folder = trim($data_source['image_folder'], '/');
			$directory = $folder.'/';
		}

		$images = glob($directory."*.{jpg,png}", GLOB_BRACE);

		if (!$images)
		{
			$images = array_merge(glob($directory."*.jpg"),glob($directory."*.png"));
		}

		$count = count($images);

		if ($count > $globalLimit)
		{
			$count = $globalLimit;
		}

		return $count;
	}

	// Get Images from folder
	public function getFolderImages($data_source, $startLimit, $pageLimit, $globalLimit)
	{
		$app = JFactory::getApplication();
		
		if (!isset($data_source['image_folder']) || !$data_source['image_folder'])
		{
			if (strstr($data_source['fold_folder'], '/'))
			{
				$folder = substr($data_source['fold_folder'], strrpos($data_source['fold_folder'], '/') + 1);
			}
			else
			{
				$folder = $data_source['fold_folder'];
			}

			$directory = 'media/minitekslider/'.$folder.'/';
		}
		else
		{
			$folder = trim($data_source['image_folder'], '/');
			$directory = $folder.'/';
		}

		$images = glob($directory."*.{jpg,png}", GLOB_BRACE);

		if (!$images)
		{
			$images = array_merge(glob($directory."*.jpg"),glob($directory."*.png"));
		}

		foreach ($images as $key => $value)
		{
			$images[$key] = new stdClass();
			$images[$key]->path = $value;
			$images[$key]->title = preg_replace('/\\.[^.\\s]{3,4}$/', '', basename($value));
			$images[$key]->created = date('Y-m-d H:i:s', filemtime($value));
		}

		// Ordering direction
		if ($data_source['fold_ordering_direction'] == 'ASC')
		{
			$dir = SORT_ASC;
		}
		else
		{
			$dir = SORT_DESC;
		}

		// Order by title and date
		if ($data_source['fold_ordering'] == 'title')
		{
			$title = array();
			$created = array();

			foreach ($images as $key => $row)
			{
				$title[$key] = $row->title;
				$created[$key] = $row->created;
			}

			array_multisort($title, $dir, $created, $dir, $images);
		}

		// Order by date and title
		if ($data_source['fold_ordering'] == 'created')
		{
			$created = array();
			$title = array();

			foreach ($images as $key => $row)
			{
				$created[$key] = $row->created;
				$title[$key] = $row->title;
			}

			array_multisort($created, $dir, $title, $dir, $images);
		}

		// Random order
		if ($data_source['fold_ordering'] == 'random')
		{
			shuffle($images);
		}

		// Set the list start limit
		$page = $app->input->get('page', '', 'INT');

		if (!$page || $page == 1) 
		{
			$limit	= $startLimit;
			$start = 0;
		} 
		else 
		{
			$start_limit = $startLimit;
			$limit = $pageLimit;
			$start = $start_limit + (($page - 2) * $limit);
			$pagination = $app->input->get('pagination', '');
			
			// Pagination: Append / Infinite
			if ($app->input->get('filters') == 'filters' && ($pagination == 1 || $pagination == '4')) 
			{
				$start = 0;
				$limit = $start_limit + (($page - 1) * $limit);
			}

			if ($start < $globalLimit) 
			{
				if ($start + $pageLimit >= $globalLimit) 
				{
					$limit = $globalLimit - $start;
				}
			} 
			else 
			{
				$limit = 0;
			}
		}

		// Limit items according to pagination
		$images = array_slice($images, $start, $limit);

		return $images;
	}
}
